@@ -30,6 +30,7 @@
 #include "gnome-settings-plugin-info.h"
 #include "gnome-settings-module.h"
 #include "gnome-settings-plugin.h"
+#include "gnome-settings-profile.h"
 
 #define GNOME_SETTINGS_PLUGIN_INFO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNOME_TYPE_SETTINGS_PLUGIN_INFO, GnomeSettingsPluginInfoPrivate))
 
@@ -166,6 +167,15 @@ gnome_settings_plugin_info_init (GnomeSettingsPluginInfo *info)
         info->priv->client = gconf_client_get_default ();
 }
 
+static void
+debug_info (GnomeSettingsPluginInfo *info)
+{
+        g_debug ("GnomeSettingsPluginInfo: name='%s' file='%s' location='%s'",
+                 info->priv->name,
+                 info->priv->file,
+                 info->priv->location);
+}
+
 static gboolean
 gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
                                            const char              *filename)
@@ -175,6 +185,8 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
         int       priority;
         gboolean  ret;
 
+        gnome_settings_profile_start (NULL);
+
         ret = FALSE;
 
         info->priv->file = g_strdup (filename);
@@ -202,13 +214,14 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
         if ((str != NULL) && (*str != '\0')) {
                 info->priv->location = str;
         } else {
+                g_free (str);
                 g_warning ("Could not find 'Module' in %s", filename);
                 goto out;
         }
 
         /* Get the loader for this plugin */
         str = g_key_file_get_string (plugin_file, PLUGIN_GROUP, "Loader", NULL);
-        if (str && strcmp(str, "python") == 0) {
+        if (str != NULL && strcmp (str, "python") == 0) {
                 info->priv->loader = GNOME_SETTINGS_PLUGIN_LOADER_PY;
 #ifndef ENABLE_PYTHON
                 g_warning ("Cannot load Python plugin '%s' since gnome_settings was not "
@@ -222,7 +235,7 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         /* Get Name */
         str = g_key_file_get_locale_string (plugin_file, PLUGIN_GROUP, "Name", NULL, NULL);
-        if (str) {
+        if (str != NULL) {
                 info->priv->name = str;
         } else {
                 g_warning ("Could not find 'Name' in %s", filename);
@@ -231,7 +244,7 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         /* Get Description */
         str = g_key_file_get_locale_string (plugin_file, PLUGIN_GROUP, "Description", NULL, NULL);
-        if (str) {
+        if (str != NULL) {
                 info->priv->desc = str;
         } else {
                 g_debug ("Could not find 'Description' in %s", filename);
@@ -245,7 +258,7 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         /* Get Copyright */
         str = g_key_file_get_string (plugin_file, PLUGIN_GROUP, "Copyright", NULL);
-        if (str) {
+        if (str != NULL) {
                 info->priv->copyright = str;
         } else {
                 g_debug ("Could not find 'Copyright' in %s", filename);
@@ -253,7 +266,7 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         /* Get Website */
         str = g_key_file_get_string (plugin_file, PLUGIN_GROUP, "Website", NULL);
-        if (str) {
+        if (str != NULL) {
                 info->priv->website = str;
         } else {
                 g_debug ("Could not find 'Website' in %s", filename);
@@ -269,12 +282,16 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         g_key_file_free (plugin_file);
 
+        debug_info (info);
+
         /* If we know nothing about the availability of the plugin,
            set it as available */
         info->priv->available = TRUE;
 
         ret = TRUE;
  out:
+        gnome_settings_profile_end (NULL);
+
         return ret;
 }
 
@@ -341,7 +358,7 @@ _deactivate_plugin (GnomeSettingsPluginInfo *info)
 gboolean
 gnome_settings_plugin_info_deactivate (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, FALSE);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
 
         if (!info->priv->active || !info->priv->available) {
                 return TRUE;
@@ -359,15 +376,20 @@ gnome_settings_plugin_info_deactivate (GnomeSettingsPluginInfo *info)
 static gboolean
 load_plugin_module (GnomeSettingsPluginInfo *info)
 {
-        char *path;
-        char *dirname;
+        char    *path;
+        char    *dirname;
+        gboolean ret;
 
-        g_return_val_if_fail (info != NULL, FALSE);
+        ret = FALSE;
+
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
         g_return_val_if_fail (info->priv->file != NULL, FALSE);
         g_return_val_if_fail (info->priv->location != NULL, FALSE);
         g_return_val_if_fail (info->priv->plugin == NULL, FALSE);
         g_return_val_if_fail (info->priv->available, FALSE);
 
+        gnome_settings_profile_start (NULL);
+
         switch (info->priv->loader) {
                 case GNOME_SETTINGS_PLUGIN_LOADER_C:
                         dirname = g_path_get_dirname (info->priv->file);
@@ -395,7 +417,7 @@ load_plugin_module (GnomeSettingsPluginInfo *info)
                                            "was not able to initialize the Python interpreter.",
                                            info->priv->name);
 
-                                return FALSE;
+                                goto out;
                         }
 
                         dir = g_path_get_dirname (info->priv->file);
@@ -439,7 +461,7 @@ load_plugin_module (GnomeSettingsPluginInfo *info)
                 /* Mark plugin as unavailable and fails */
                 info->priv->available = FALSE;
 
-                return FALSE;
+                goto out;
         }
 
         switch (info->priv->loader) {
@@ -460,8 +482,10 @@ load_plugin_module (GnomeSettingsPluginInfo *info)
         }
 
         g_type_module_unuse (info->priv->module);
-
-        return TRUE;
+        ret = TRUE;
+ out:
+        gnome_settings_profile_end (NULL);
+        return ret;
 }
 
 static gboolean
@@ -474,8 +498,9 @@ _activate_plugin (GnomeSettingsPluginInfo *info)
                 return FALSE;
         }
 
-        if (info->priv->plugin == NULL)
+        if (info->priv->plugin == NULL) {
                 res = load_plugin_module (info);
+        }
 
         if (res) {
                 gnome_settings_plugin_activate (info->priv->plugin);
@@ -491,7 +516,7 @@ gboolean
 gnome_settings_plugin_info_activate (GnomeSettingsPluginInfo *info)
 {
 
-        g_return_val_if_fail (info != NULL, FALSE);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
 
         if (! info->priv->available) {
                 return FALSE;
@@ -512,7 +537,7 @@ gnome_settings_plugin_info_activate (GnomeSettingsPluginInfo *info)
 gboolean
 gnome_settings_plugin_info_is_active (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, FALSE);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
 
         return (info->priv->available && info->priv->active);
 }
@@ -520,7 +545,7 @@ gnome_settings_plugin_info_is_active (GnomeSettingsPluginInfo *info)
 gboolean
 gnome_settings_plugin_info_get_enabled (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, FALSE);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
 
         return (info->priv->enabled);
 }
@@ -528,7 +553,7 @@ gnome_settings_plugin_info_get_enabled (GnomeSettingsPluginInfo *info)
 gboolean
 gnome_settings_plugin_info_is_available (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, FALSE);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), FALSE);
 
         return (info->priv->available != FALSE);
 }
@@ -536,7 +561,7 @@ gnome_settings_plugin_info_is_available (GnomeSettingsPluginInfo *info)
 const char *
 gnome_settings_plugin_info_get_name (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), NULL);
 
         return info->priv->name;
 }
@@ -544,7 +569,7 @@ gnome_settings_plugin_info_get_name (GnomeSettingsPluginInfo *info)
 const char *
 gnome_settings_plugin_info_get_description (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), NULL);
 
         return info->priv->desc;
 }
@@ -552,7 +577,7 @@ gnome_settings_plugin_info_get_description (GnomeSettingsPluginInfo *info)
 const char **
 gnome_settings_plugin_info_get_authors (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, (const char **)NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), (const char **)NULL);
 
         return (const char **)info->priv->authors;
 }
@@ -560,7 +585,7 @@ gnome_settings_plugin_info_get_authors (GnomeSettingsPluginInfo *info)
 const char *
 gnome_settings_plugin_info_get_website (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), NULL);
 
         return info->priv->website;
 }
@@ -568,7 +593,7 @@ gnome_settings_plugin_info_get_website (GnomeSettingsPluginInfo *info)
 const char *
 gnome_settings_plugin_info_get_copyright (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), NULL);
 
         return info->priv->copyright;
 }
@@ -577,7 +602,7 @@ gnome_settings_plugin_info_get_copyright (GnomeSettingsPluginInfo *info)
 const char *
 gnome_settings_plugin_info_get_location (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, NULL);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), NULL);
 
         return info->priv->location;
 }
@@ -585,7 +610,7 @@ gnome_settings_plugin_info_get_location (GnomeSettingsPluginInfo *info)
 int
 gnome_settings_plugin_info_get_priority (GnomeSettingsPluginInfo *info)
 {
-        g_return_val_if_fail (info != NULL, PLUGIN_PRIORITY_DEFAULT);
+        g_return_val_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info), PLUGIN_PRIORITY_DEFAULT);
 
         return info->priv->priority;
 }
@@ -594,7 +619,7 @@ void
 gnome_settings_plugin_info_set_priority (GnomeSettingsPluginInfo *info,
                                          int                      priority)
 {
-        g_return_if_fail (info != NULL);
+        g_return_if_fail (GNOME_IS_SETTINGS_PLUGIN_INFO (info));
 
         info->priv->priority = priority;
 }
