@@ -45,6 +45,7 @@
 #include <X11/keysym.h>
 #endif
 
+#include "gnome-settings-profile.h"
 #include "gsd-keyboard-manager.h"
 
 #include "gsd-keyboard-xkb.h"
@@ -134,12 +135,17 @@ gsd_keyboard_get_hostname_key (const char *subkey)
         if (gethostname (hostname, sizeof (hostname)) == 0 &&
             strcmp (hostname, "localhost") != 0 &&
             strcmp (hostname, "localhost.localdomain") != 0) {
-                char *key = g_strconcat (GSD_KEYBOARD_KEY
-                                         "/host-",
-                                         hostname,
-                                         "/0/",
-                                         subkey,
-                                         (char *)NULL);
+                char *escaped;
+                char *key;
+
+                escaped = gconf_escape_key (hostname, -1);
+                key = g_strconcat (GSD_KEYBOARD_KEY
+                                   "/host-",
+                                   escaped,
+                                   "/0/",
+                                   subkey,
+                                   (char *)NULL);
+                g_free (escaped);
                 return key;
         } else
                 return NULL;
@@ -405,11 +411,14 @@ gsd_keyboard_manager_start (GsdKeyboardManager *manager,
 {
         GConfClient *client;
 
+        gnome_settings_profile_start (NULL);
+
         client = gconf_client_get_default ();
         g_debug ("Starting keyboard manager");
         /* Essential - xkb initialization should happen before */
         gsd_keyboard_xkb_set_post_activation_callback ((PostActivationCallback) gsd_load_modmap_files, NULL);
         gsd_keyboard_xkb_init (client);
+        gsd_keyboard_xkb_load (client);
 
         register_config_callback (manager,
                                   GSD_KEYBOARD_KEY,
@@ -418,8 +427,11 @@ gsd_keyboard_manager_start (GsdKeyboardManager *manager,
         numlock_install_xkb_callback ();
 #endif /* HAVE_X11_EXTENSIONS_XKB_H */
 
+        apply_settings (client, 0, NULL, manager);
         g_object_unref (client);
 
+        gnome_settings_profile_end (NULL);
+
         return TRUE;
 }
 
