@@ -29,8 +29,6 @@
 #include <string.h>
 #include <errno.h>
 
-#include <locale.h>
-
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
@@ -39,6 +37,7 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
+#include "gnome-settings-profile.h"
 #include "gsd-xsettings-manager.h"
 #include "xsettings-manager.h"
 
@@ -85,10 +84,6 @@ struct GnomeXSettingsManagerPrivate
         XSettingsManager **managers;
 };
 
-enum {
-        PROP_0,
-};
-
 static void     gnome_xsettings_manager_class_init  (GnomeXSettingsManagerClass *klass);
 static void     gnome_xsettings_manager_init        (GnomeXSettingsManager      *xsettings_manager);
 static void     gnome_xsettings_manager_finalize    (GObject                  *object);
@@ -361,6 +356,9 @@ xft_settings_set_xsettings (GnomeXSettingsManager *manager,
                             GnomeXftSettings      *settings)
 {
         int i;
+
+        gnome_settings_profile_start (NULL);
+
         for (i = 0; manager->priv->managers [i]; i++) {
                 xsettings_manager_set_int (manager->priv->managers [i], "Xft/Antialias", settings->antialias);
                 xsettings_manager_set_int (manager->priv->managers [i], "Xft/Hinting", settings->hinting);
@@ -368,6 +366,7 @@ xft_settings_set_xsettings (GnomeXSettingsManager *manager,
                 xsettings_manager_set_int (manager->priv->managers [i], "Xft/DPI", settings->dpi);
                 xsettings_manager_set_string (manager->priv->managers [i], "Xft/RGBA", settings->rgba);
         }
+        gnome_settings_profile_end (NULL);
 }
 
 static gboolean
@@ -455,17 +454,17 @@ xft_settings_set_xresources (GnomeXftSettings *settings)
 {
         const char *command;
         GString    *add_string;
-        char       *old_locale;
+        char        dpibuf[G_ASCII_DTOSTR_BUF_SIZE];
+
+        gnome_settings_profile_start (NULL);
 
         command = "xrdb -nocpp -merge";
 
         add_string = g_string_new (NULL);
-        old_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 
-        setlocale (LC_NUMERIC, "C");
         g_string_append_printf (add_string,
-                                "Xft.dpi: %f\n",
-                                settings->dpi / 1024.0);
+                                "Xft.dpi: %s\n",
+                                g_ascii_dtostr (dpibuf, sizeof (dpibuf), (double) settings->dpi / 1024.0));
         g_string_append_printf (add_string,
                                 "Xft.antialias: %d\n",
                                 settings->antialias);
@@ -482,8 +481,8 @@ xft_settings_set_xresources (GnomeXftSettings *settings)
         spawn_with_input (command, add_string->str);
 
         g_string_free (add_string, TRUE);
-        setlocale (LC_NUMERIC, old_locale);
-        g_free (old_locale);
+
+        gnome_settings_profile_end (NULL);
 }
 
 /* We mirror the Xft properties both through XSETTINGS and through
@@ -495,9 +494,13 @@ update_xft_settings (GnomeXSettingsManager *manager,
 {
         GnomeXftSettings settings;
 
+        gnome_settings_profile_start (NULL);
+
         xft_settings_get (client, &settings);
         xft_settings_set_xsettings (manager, &settings);
         xft_settings_set_xresources (&settings);
+
+        gnome_settings_profile_end (NULL);
 }
 
 static void
@@ -574,6 +577,7 @@ gnome_xsettings_manager_start (GnomeXSettingsManager *manager,
         int          i;
 
         g_debug ("Starting xsettings manager");
+        gnome_settings_profile_start (NULL);
 
         client = gconf_client_get_default ();
 
@@ -599,12 +603,12 @@ gnome_xsettings_manager_start (GnomeXSettingsManager *manager,
                 }
         }
 
-        g_object_unref (client);
-
 #ifdef HAVE_XFT2
         update_xft_settings (manager, client);
 #endif /* HAVE_XFT */
 
+        g_object_unref (client);
+
         for (i = 0; manager->priv->managers [i]; i++)
                 xsettings_manager_set_string (manager->priv->managers [i],
                                               "Net/FallbackIconTheme",
@@ -614,6 +618,8 @@ gnome_xsettings_manager_start (GnomeXSettingsManager *manager,
                 xsettings_manager_notify (manager->priv->managers [i]);
         }
 
+        gnome_settings_profile_end (NULL);
+
         return TRUE;
 }
 
